@@ -3,7 +3,6 @@ import { connect, ConnectedProps } from 'react-redux';
 import AutoSizer from 'react-virtualized-auto-sizer';
 
 import {
-  ArrayVector,
   DataFrame,
   dateTime,
   FieldType,
@@ -104,16 +103,16 @@ class DataSourceInsights extends PureComponent<Props, State> {
     valueField: keyof DataSourceDailySummaryDTO,
     valueFieldType: FieldType
   ): DataFrame {
-    const time = new ArrayVector<number>([]);
-    const values = new ArrayVector<any>([]);
+    const time: number[] = [];
+    const values: any[] = [];
 
     data.forEach((dailySummary) => {
-      time.buffer.push(dateTime(dailySummary.day, DAILY_SUMMARY_DATE_FORMAT).valueOf());
+      time.push(dateTime(dailySummary.day, DAILY_SUMMARY_DATE_FORMAT).valueOf());
       let value = dailySummary[valueField];
       if (valueField === 'loadDuration') {
         value = dailySummary.queries ? dailySummary.loadDuration / (dailySummary.queries * 1000000) : 0;
       }
-      values.buffer.push(value);
+      values.push(value);
     });
 
     return {
